import React from 'react';
import 'slate';
import tinycolor from 'tinycolor2';

var defineProperty = function (obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
};

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var defaultStyle = {
  textDecoration: "inherit",
  textDecorationColor: "inherit"
};

function createRenderMark(opt) {
  var type = opt.type,
      dataField = opt.data,
      styleFields = opt.styles,
      alpha = opt.alpha;

  return function (props) {
    if (props.mark.type === type) {
      var _children = props.children,
          _attributes = props.attributes,
          data = props.mark.data;

      var _ref = _attributes || {},
          style = _ref.style;

      var color = tinycolor(data.get(dataField));
      style = _extends({}, defaultStyle, style, {
        textDecoration: "inherit",
        decorationStyle: "initial"
      }, styleFields.reduce(function (acc, styleField) {
        return _extends({}, acc, defineProperty({}, styleField, color.setAlpha(alpha).toRgbString()));
      }, {}));
      return React.createElement(
        "span",
        _extends({}, _attributes, { style: style }),
        _children
      );
    }
    return undefined;
  };
}

function createRenderer(opts) {
  return {
    renderMark: createRenderMark(opts)
  };
}

export default createRenderer;
export { createRenderer };
//# sourceMappingURL=slate-kit-highlight-text-renderer.es.js.map
